==> snk-browser-helper-print-0.0.3.tgz: package/src/browserHelper/message.js <==
class Message {

  constructor(props) {
    this.props = props;
    const { env } = this.props;
    this.root = $("<div class='snk-bh-mes-root' />");
    // this.dowloadURL = `https://h5file-test.sinosafe.com.cn/${env==="pro"?"snkhelper":"snkhelper-uat"}/华安网页助手安装压缩包.zip`
    this.dowloadURL = `https://proxytest.sinosafe.com.cn/zzlp01/ec/res/api/anysign-web/print/exe/printHandler.exe`;
    // 依赖vc++ vc_redist.x86 2015
    this.VCPlusPlusURL = 'https://h5file-test.sinosafe.com.cn/huaanresource/vc_redist.x86.exe';
  }
  
  showLoading = (str) => {
    this.root.show();
    this.root.empty();
    this.root.append($(`<div class='snk-wbh-loading-root'><div class="snk-wbh-loading">
    <div class="rect1"></div>
    <div class="rect2"></div>
    <div class="rect3"></div>
    <div class="rect4"></div>
    <div class="rect5"></div>
  </div><div class='snk-wbh-loading-label'>${str}</div>
  </div>`));
    this._createCloseBtn();
  }

  showDownloadVC = () => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        const blockone = $(`<div class='snk-wbh-mes-one-section'>您的电脑缺少运行必要组件;请下载安装修复！<a style='font-weight:bold;' download href='${this.VCPlusPlusURL}'>点击下载</a>;进行安装,完成安装后,</div>`);
        blockone.append(this._createReStart());
        inner.append(blockone);
        mesRoot.append(inner);
      }
    });
  }

  showAppMustUpdate = (update) => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        const blockone = $(`<div class='snk-wbh-mes-one-section'><span class='snk-wbh-mes-update'>
        您当前安装的华安网页助手版本较低，需要更新才能使用该功能！
        </span></div>`);
        const updateBtn = $(`<span class='snk-wbh-restart'>点击更新</span>`);
        updateBtn.bind("click", () => {
          update();
        });
        blockone.append(updateBtn);
        inner.append(blockone);
        inner.append($(`<div style='margin-top:60px;font-size:14px;'>如果更新失败,请<a href='${this.dowloadURL}' download>点击下载</a>进行安装</div>`));
        mesRoot.append(inner);
      }
    });
  }

  showWebScoketError = () => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        inner.append(`<div class='snk-wbh-mes-one-section'>
          <div style='font-weight:bold;font-size:16px'>IE连接发生异常,请按照如下进行浏览器设置：</div>
          <div style='background-color:#eee;padding:20px 10px;font-size:14px'>Internet选项->安全->本地Internet->站点，把所有勾选取消</div>
        </div>`);
        inner.append($(`<div class='snk-wbh-mes-one-section'>如果无效请下载安装修复！<a style='font-weight:bold;' download href='${this.dowloadURL}'>点击下载</a>;解压后点击"点击进行安装"<span style='color:red'>以管理员身份</span>进行安装,完成安装后重试.</div>`));
      
        mesRoot.append(inner);
      }
    });
  }

  showDownload = () => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        inner.append($(`<div class='snk-wbh-mes-one-section'>请下载安装修复！<a style='font-weight:bold;' download href='${this.dowloadURL}'>点击下载</a>;解压后点击"点击进行安装.bat"<span style='color:red'>以管理员身份</span>进行安装,完成安装后重试.</div>`));
        inner.append(`<div style='color:#830000;font-size:12px;padding-top:5px;padding-left:20px;'><br />
        <div>注意1.如果安装期间被杀毒软件拦截，请允许当前操作</div><br />
        <div>注意2.安装过程较慢,请耐心等待</div><br />
        <div>注意3.如遇安装失败,请再次尝试安装</div>
        </div>`);
        mesRoot.append(inner);
      }
    });
  }

  show = ({ isCloseDialog = true, html, render }) => {
    const { dialog } = this.props;
    this.root.show();
    this.root.empty();
    if(render) {
      render(this.root);
    } else {
      if(html.indexOf('未找到扫描仪')>=0) {
        html = '未找到扫描仪设备,请安装相应型号扫描仪驱动,并添加扫描仪后再试！';
      }
      this.root.append($(`<div class='snk-wbh-commonmes'>${html}</div>`));
    }
    this._createCloseBtn(()=>{
      if(isCloseDialog) {
        dialog.close();
      } else {
        this.hide();
      }
    });
  }

  showDisConnect = () => {
    const { dialog, reStartCallBack } = this.props;
    this.show({
      isCloseDialog: dialog.getResult() > 0 ? false: true,
      render: (wrapper) => {
        const inner = $('<div class="snk-wbh-commonmes" />');
        inner.append($(`<div style='color:red'>华安网页助手程序意外退出，失去连接!</div>`));
        const reConnct = $(`<span class='snk-wbh-restart'>点击重试</span>`);
        reConnct.bind("click", () => {
          this.hide();
          dialog.reStart();
          if(reStartCallBack) {
            reStartCallBack();
          }
        });
        inner.append(reConnct);
        if(dialog.step === 'callelectronsuccess') {
          inner.append($(`<div style='margin-top:70px;font-size:16px;'>如果重试无效的话,请<a href='${this.dowloadURL}' download>点击下载</a>安装进行修复,再次重试</div>`));
        } else if(dialog.step === 'callscannersuccess'){
          inner.append($(`<div style='margin-top:70px;font-size:16px;'>当前扫描仪驱动无法使用，请点击重试，重新选择，或者安装正确的扫描仪驱动并添加扫描仪再试！</div>`));
          window.callScannerError = true;
        }
        wrapper.append(inner);
      }
    });
  }


  _createCloseBtn = (cb) => {
    const { dialog } = this.props;
    const closeBtn = $("<span class='snk-bh-closebtn'>关闭</span>");
    closeBtn.bind('click', () => {
      if(cb) {
        cb();
      } else {
        dialog.close();
      }
    });
    this.root.append(closeBtn);
  }

  showCallElectronFail = () => {
    this.show({
      isCloseDialog: true,
      render: (wrapper) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        
        inner.append("<div class='snk-wbh-mes-one-title'>唤起华安网页助手失败！</div>");
        inner.append("<div class='snk-wbh-mes-one-sectitle'>请检查是否正确安装华安网页助手</div>");
        const blockone = $(`<div class='snk-wbh-mes-one-section'> <span style='color:red;font-weight:bold;font-size:25px;'>还没有安装：</span>请<a style='font-weight:bold;' download href='${this.dowloadURL}'>点击下载</a>,解压后<span style='color:red'>并以管理员身份运行</span>【点击进行安装.bat】进行安装,安装完成,然后</div>`);
        blockone.append(this._createReStart());
        inner.append(blockone);
        inner.append(`<div style='color:#020000;font-size:12px;padding-top:5px;padding-left:20px;'><br />
        <div>注意1.如果安装期间被杀毒软件拦截，请允许当前操作</div><br />
          <div>注意2.安装过程较慢,请耐心等待</div><br />
          <div>注意3.如遇安装失败,请再次尝试安装</div>
          </div>`);
        const blocktwo = $("<div class='snk-wbh-mes-one-section'><span style='color:green;font-weight:bold;font-size:25px;'>已经安装了：</span>请在你的电脑上找到【华安网页助手】点击运行,然后</div>");
        blocktwo.append(this._createReStart());
        inner.append(blocktwo);
        wrapper.append(inner);
      }
    });
  }

  _createReStart = () => {
    const { dialog} = this.props;
    const reConnct = $("<span class='snk-wbh-one-restart'>点击重试</span>");
    reConnct.bind("click", () => {
      this.hide();
      dialog.reStart();
    });
    return reConnct;
  }

  hide = () => {
    this.root.hide();
  }

}

export default Message;

==> snk-browser-helper-print-0.0.7.tgz: package/src/browserHelper/message.js <==
class Message {

  constructor(props) {
    this.props = props;
    const { env } = this.props;
    this.root = $("<div class='snk-bh-mes-root' />");
    // this.dowloadURL = `https://h5file-test.sinosafe.com.cn/${env==="pro"?"snkhelper":"snkhelper-uat"}/华安网页助手安装压缩包.zip`
    this.dowloadURL = `https://proxytest.sinosafe.com.cn/zzlp01/ec/res/api/anysign-web/print/exe/x64/printHandler.exe`;
    this.dowloadURL1 = `https://proxytest.sinosafe.com.cn/zzlp01/ec/res/api/anysign-web/print/exe/x86/printHandler.exe`;
    // 依赖vc++ vc_redist.x86 2015
    this.VCPlusPlusURL = 'https://h5file-test.sinosafe.com.cn/huaanresource/vc_redist.x86.exe';
  }
  
  showLoading = (str) => {
    this.root.show();
    this.root.empty();
    this.root.append($(`<div class='snk-wbh-loading-root'><div class="snk-wbh-loading">
    <div class="rect1"></div>
    <div class="rect2"></div>
    <div class="rect3"></div>
    <div class="rect4"></div>
    <div class="rect5"></div>
  </div><div class='snk-wbh-loading-label'>${str}</div>
  </div>`));
    this._createCloseBtn();
  }

  showDownloadVC = () => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        const blockone = $(`<div class='snk-wbh-mes-one-section'>您的电脑缺少运行必要组件;请下载安装修复！<a style='font-weight:bold;' download href='${this.VCPlusPlusURL}'>点击下载</a>;进行安装,完成安装后,</div>`);
        blockone.append(this._createReStart());
        inner.append(blockone);
        mesRoot.append(inner);
      }
    });
  }

  showAppMustUpdate = (update) => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        const blockone = $(`<div class='snk-wbh-mes-one-section'><span class='snk-wbh-mes-update'>
        您当前安装的打印助手版本较低，需要更新才能使用该功能！
        </span></div>`);
        const updateBtn = $(`<span class='snk-wbh-restart'>点击更新</span>`);
        updateBtn.bind("click", () => {
          update();
        });
        blockone.append(updateBtn);
        inner.append(blockone);
        inner.append($(`<div style='margin-top:60px;font-size:14px;'>如果更新失败,请<a href='${this.dowloadURL}' download>点击下载</a>进行安装</div>`));
        mesRoot.append(inner);
      }
    });
  }

  showWebScoketError = () => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        inner.append(`<div class='snk-wbh-mes-one-section'>
          <div style='font-weight:bold;font-size:16px'>IE连接发生异常,请按照如下进行浏览器设置：</div>
          <div style='background-color:#eee;padding:20px 10px;font-size:14px'>Internet选项->安全->本地Internet->站点，把所有勾选取消</div>
        </div>`);
        inner.append($(`<div class='snk-wbh-mes-one-section'>如果无效请下载安装修复！<a style='font-weight:bold;' download href='${this.dowloadURL}'>点击下载</a>;解压后点击"点击进行安装"<span style='color:red'>以管理员身份</span>进行安装,完成安装后重试.</div>`));
      
        mesRoot.append(inner);
      }
    });
  }

  showDownload = () => {
    this.show({
      render:(mesRoot) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        inner.append($(`<div class='snk-wbh-mes-one-section'>请下载安装修复！<a style='font-weight:bold;' download href='${this.dowloadURL}'>点击下载</a>;解压后点击"点击进行安装.bat"<span style='color:red'>以管理员身份</span>进行安装,完成安装后重试.</div>`));
        inner.append(`<div style='color:#830000;font-size:12px;padding-top:5px;padding-left:20px;'><br />
        <div>注意1.如果安装期间被杀毒软件拦截，请允许当前操作</div><br />
        <div>注意2.安装过程较慢,请耐心等待</div><br />
        <div>注意3.如遇安装失败,请再次尝试安装</div>
        </div>`);
        mesRoot.append(inner);
      }
    });
  }

  show = ({ isCloseDialog = true, html, render }) => {
    const { dialog } = this.props;
    this.root.show();
    this.root.empty();
    if(render) {
      render(this.root);
    } else {
      if(html.indexOf('未找到扫描仪')>=0) {
        html = '未找到扫描仪设备,请安装相应型号扫描仪驱动,并添加扫描仪后再试！';
      }
      this.root.append($(`<div class='snk-wbh-commonmes'>${html}</div>`));
    }
    this._createCloseBtn(()=>{
      if(isCloseDialog) {
        dialog.close();
      } else {
        this.hide();
      }
    });
  }

  showDisConnect = () => {
    const { dialog, reStartCallBack } = this.props;
    this.show({
      isCloseDialog: dialog.getResult() > 0 ? false: true,
      render: (wrapper) => {
        const inner = $('<div class="snk-wbh-commonmes" />');
        inner.append($(`<div style='color:red'>打印助手程序意外退出，失去连接!</div>`));
        const reConnct = $(`<span class='snk-wbh-restart'>点击重试</span>`);
        reConnct.bind("click", () => {
          this.hide();
          dialog.reStart();
          if(reStartCallBack) {
            reStartCallBack();
          }
        });
        inner.append(reConnct);
        if(dialog.step === 'callelectronsuccess') {
          inner.append($(`<div style='margin-top:70px;font-size:16px;'>如果重试无效的话,请<a href='${this.dowloadURL}' download>点击下载</a>安装进行修复,再次重试</div>`));
        } else if(dialog.step === 'callscannersuccess'){
          inner.append($(`<div style='margin-top:70px;font-size:16px;'>当前扫描仪驱动无法使用，请点击重试，重新选择，或者安装正确的扫描仪驱动并添加扫描仪再试！</div>`));
          window.callScannerError = true;
        }
        wrapper.append(inner);
      }
    });
  }


  _createCloseBtn = (cb) => {
    const { dialog } = this.props;
    const closeBtn = $("<span class='snk-bh-closebtn'>关闭</span>");
    closeBtn.bind('click', () => {
      if(cb) {
        cb();
      } else {
        dialog.close();
      }
    });
    this.root.append(closeBtn);
  }

  showCallElectronFail = () => {
    this.show({
      isCloseDialog: true,
      render: (wrapper) => {
        const inner = $("<div class='snk-wbh-mes-one'></div>");
        
        inner.append("<div class='snk-wbh-mes-one-title'>唤起打印助手失败！</div>");
        inner.append("<div class='snk-wbh-mes-one-sectitle'>请检查是否正确安装打印助手</div>");
        const blockone = $(`<div class='snk-wbh-mes-one-section'> 
        <span class='snk-wbh-mes-one-section' style='color:red;font-weight:bold;font-size:18px;'>如还没有安装,请根据电脑系统点击下载安装：</span>
        (<a style='font-weight:bold;' download href='${this.dowloadURL}'>Win 64位</a>)、(<a style='font-weight:bold;' download href='${this.dowloadURL1}'>Win 32位</a>),
        <span>然后</span></div>`);
        blockone.append(this._createReStart());
        inner.append(blockone);
        inner.append(`<div style='color:#020000;font-size:12px;padding-top:5px;padding-left:20px;'><br />
        <div>注意1.如果安装期间被杀毒软件拦截，请允许当前操作</div><br />
          <div>注意2.安装过程较慢,请耐心等待</div><br />
          <div>注意3.如遇安装失败,请再次尝试安装</div>
          </div>`);
        const blocktwo = $("<div class='snk-wbh-mes-one-section'><span style='color:green;font-weight:bold;font-size:25px;'>已经安装了：</span>请在你的电脑上找到【打印助手】点击运行,然后</div>");
        blocktwo.append(this._createReStart());
        inner.append(blocktwo);
        wrapper.append(inner);
      }
    });
  }

  _createReStart = () => {
    const { dialog} = this.props;
    const reConnct = $("<span class='snk-wbh-one-restart'>点击重试</span>");
    reConnct.bind("click", () => {
      this.hide();
      dialog.reStart();
    });
    return reConnct;
  }

  hide = () => {
    this.root.hide();
  }

}

export default Message;
